if [ -z ${CONDA_BUILD+x} ]; then
    source /micromamba/conda-bld/fsl-gui-desktop_1698334863119/work/build_env_setup.sh
fi
#!/usr/bin/env bash

export FSLDIR=$PREFIX
export FSLDEVDIR=$PREFIX

. $FSLDIR/etc/fslconf/fsl-devel.sh

mkdir -p $PREFIX/src/
cp -r $(pwd) $PREFIX/src/$PKG_NAME

export GUI_NAME="fsl-desktop"

# use uname to get the system type
if [[ $(uname) == "Darwin" ]]; then
    export SYSTEM_TYPE="Mac"
    export SYSTEM_TYPE_OUT="darwin"
else
    export SYSTEM_TYPE="Linux"
    export SYSTEM_TYPE_OUT="linux"
fi

# use uname to get the arch
if [[ $(uname -m) == "x86_64" ]]; then
    export ARCH="X64"
    export ARCH_OUT="x64"
else
    export ARCH="Arm64"
    export ARCH_OUT="arm64"
fi

# concatenate the system type and arch to get the platform
export PLATFORM=$SYSTEM_TYPE$ARCH

# install gui deps
npm install
# build the application
npm run "make$PLATFORM"
# the npm run build command will create an out folder with the electron app
mkdir -p $PREFIX/share/fsl/gui/desktop
# unzip the electron app into the proper location
unzip -qq -o ./out/make/zip/$SYSTEM_TYPE_OUT/$ARCH_OUT/*.zip -d $PREFIX/share/fsl/gui/desktop
# copy the app zip to the destination folder
# cp -r ./out/make/zip/$SYSTEM_TYPE_OUT/$ARCH_OUT/* $PREFIX/share/fsl/gui/desktop/

# if darwin, create a wrapper for fsl-desktop from the .app bundle
if [[ "${OSTYPE}" == "darwin"* ]]; then
    target="${PREFIX}/share/fsl/gui/desktop/fsl-desktop.app/Contents/MacOS/fsl-desktop"
else
    target="${PREFIX}/share/fsl/gui/desktop/fsl-desktop-linux-x64/fsl-desktop"
fi

wrapper="${PREFIX}/bin/fsl"

# make sure the bin folder exists
mkdir -p "${PREFIX}/bin"

# remove wrapper script if it already exists
if [ -e "${wrapper}" ]; then
    rm "${wrapper}"
fi

echo "#!/usr/bin/env bash" > "${wrapper}"
echo "${target} "'"$@"'   >> "${wrapper}"

# Preserve file permissions
if [[ "${OSTYPE}" == "darwin"* ]]; then
    perms=$(/usr/bin/stat -f "%A" "${target}")
    chmod ${perms} "${wrapper}"
else
    chmod --reference="${target}" "${wrapper}"
fi



